aboutsummaryrefslogtreecommitdiff
path: root/discord/client.py
diff options
context:
space:
mode:
Diffstat (limited to 'discord/client.py')
-rw-r--r--discord/client.py6
1 files changed, 4 insertions, 2 deletions
diff --git a/discord/client.py b/discord/client.py
index 4962d1e4..25408b7f 100644
--- a/discord/client.py
+++ b/discord/client.py
@@ -896,8 +896,10 @@ class Client:
temporary : bool
Denotes that the invite grants temporary membership
(i.e. they get kicked after they disconnect). Defaults to False.
- xkcd : bool
- Indicates if the invite URL is human readable. Defaults to False.
+ unique: bool
+ Indicates if a unique invite URL should be created. Defaults to True.
+ If this is set to False then it will return a previously created
+ invite.
Raises
-------